import threading

local = threading.local()

DEFAULT_HEADER_VALUE = "none"
LOG_LABEL_REQUEST_SETTING = "LOG_LABEL_REQUEST_SETTING"
MAX_REQUEST_RESPONSE_SIZE = "MAX_REQUEST_RESPONSE_SIZE"
DEFAULT_LOG_LEVEL = "DEFAULT_LOG_LEVEL"
NIM_DJANGO_REQUEST_LOG_LEVEL_NAME = "NIM_DJANGO_REQUEST_LOG_LEVEL_NAME"
ALLOWED_DYNAMIC_DEBUG_LEVEL_VALUES = ["INFO", "DEBUG", "CRITICAL", "FATAL", "ERROR", "NOTSET", "WARN", "WARNING"]
LOG_LABEL_EXCLUDE_LOG_LIST = "LOG_LABEL_EXCLUDE_LOG_LIST"
LOGGING = "LOGGING"
